==> qtjambi-uic-6.3.0-sources.jar: io/qt/uic/ui4/DomConnection.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomConnection</p>
 */
public class DomConnection extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomConnection(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomConnection instance);
    
    @io.qt.QtUninvokable
    public final void clearElementHints(){
        clearElementHints_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementHints_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementReceiver(){
        clearElementReceiver_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementReceiver_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementSender(){
        clearElementSender_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementSender_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementSignal(){
        clearElementSignal_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementSignal_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementSlot(){
        clearElementSlot_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementSlot_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomConnectionHints elementHints(){
        return elementHints_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomConnectionHints elementHints_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String elementReceiver(){
        return elementReceiver_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String elementReceiver_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String elementSender(){
        return elementSender_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String elementSender_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String elementSignal(){
        return elementSignal_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String elementSignal_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String elementSlot(){
        return elementSlot_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String elementSlot_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementHints(){
        return hasElementHints_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementHints_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementReceiver(){
        return hasElementReceiver_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementReceiver_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementSender(){
        return hasElementSender_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementSender_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementSignal(){
        return hasElementSignal_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementSignal_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementSlot(){
        return hasElementSlot_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementSlot_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setElementHints(io.qt.uic.ui4.DomConnectionHints a){
        setElementHints_native_DomConnectionHints_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementHints_native_DomConnectionHints_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final void setElementReceiver(java.lang.String a){
        setElementReceiver_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementReceiver_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementSender(java.lang.String a){
        setElementSender_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementSender_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementSignal(java.lang.String a){
        setElementSignal_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementSignal_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementSlot(java.lang.String a){
        setElementSlot_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementSlot_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomConnectionHints takeElementHints(){
        return takeElementHints_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomConnectionHints takeElementHints_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, "");
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomConnection(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.4.3-sources.jar: io/qt/uic/ui4/DomConnection.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomConnection</p>
 */
public class DomConnection extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomConnection(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomConnection instance);
    
    @io.qt.QtUninvokable
    public final void clearElementHints(){
        clearElementHints_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementHints_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementReceiver(){
        clearElementReceiver_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementReceiver_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementSender(){
        clearElementSender_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementSender_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementSignal(){
        clearElementSignal_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementSignal_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementSlot(){
        clearElementSlot_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementSlot_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomConnectionHints elementHints(){
        return elementHints_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomConnectionHints elementHints_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String elementReceiver(){
        return elementReceiver_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String elementReceiver_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String elementSender(){
        return elementSender_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String elementSender_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String elementSignal(){
        return elementSignal_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String elementSignal_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String elementSlot(){
        return elementSlot_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String elementSlot_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementHints(){
        return hasElementHints_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementHints_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementReceiver(){
        return hasElementReceiver_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementReceiver_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementSender(){
        return hasElementSender_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementSender_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementSignal(){
        return hasElementSignal_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementSignal_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementSlot(){
        return hasElementSlot_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementSlot_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setElementHints(io.qt.uic.ui4.DomConnectionHints a){
        setElementHints_native_DomConnectionHints_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementHints_native_DomConnectionHints_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final void setElementReceiver(java.lang.String a){
        setElementReceiver_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementReceiver_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementSender(java.lang.String a){
        setElementSender_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementSender_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementSignal(java.lang.String a){
        setElementSignal_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementSignal_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementSlot(java.lang.String a){
        setElementSlot_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementSlot_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomConnectionHints takeElementHints(){
        return takeElementHints_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomConnectionHints takeElementHints_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomConnection(QPrivateConstructor p) { super(p); } 
    
}
